@@ -1,13 +1,17 @@
 from importlib import util
+from typing import Literal
 
 from pydantic import BaseModel
 
 
-def _check_langchain_openai_install() -> None:
-    if not util.find_spec("langchain_openai"):
-        msg = (
-            "Please install langchain_dev_utils[standard],when use 'openai-compatible'"
-        )
+def _check_pkg_install(
+    pkg: Literal["langchain_openai", "json_repair"],
+) -> None:
+    if not util.find_spec(pkg):
+        if pkg == "langchain_openai":
+            msg = "Please install langchain_dev_utils[standard],when use 'openai-compatible'"
+        else:
+            msg = "Please install langchain_dev_utils[standard] to use ToolCallRepairMiddleware."
         raise ImportError(msg)
 
 
