@@ -1,10 +1,10 @@
 from typing import Any, Literal, NotRequired, Optional, TypedDict, Union
 
-from langchain.embeddings.base import Embeddings, _SUPPORTED_PROVIDERS, init_embeddings
+from langchain.embeddings.base import _SUPPORTED_PROVIDERS, Embeddings, init_embeddings
 from langchain_core.utils import from_env, secret_from_env
 
 from langchain_dev_utils._utils import (
-    _check_langchain_openai_install,
+    _check_pkg_install,
     _get_base_url_field_name,
 )
 
@@ -60,14 +60,17 @@ def register_embeddings_provider(
 
     Args:
         provider_name: Name of the provider to register
-        embeddings_model: Either an Embeddings class or a string identifier for a supported provider
-        base_url: The API address of the Embedding model provider (optional, valid for both types of `embeddings_model`, but mainly used when `embeddings_model` is a string and is "openai-compatible")
+        embeddings_model: Either an Embeddings class or a string identifier
+            for a supported provider
+        base_url: The API address of the Embedding model provider (optional,
+            valid for both types of `embeddings_model`, but mainly used when
+            `embeddings_model` is a string and is "openai-compatible")
 
     Raises:
         ValueError: If base_url is not provided when embeddings_model is a string
 
     Example:
-        Register with custom model class:
+        # Register with custom model class:
         >>> from langchain_dev_utils.embeddings import register_embeddings_provider, load_embeddings
         >>> from langchain_core.embeddings.fake import FakeEmbeddings
         >>>
@@ -75,9 +78,11 @@ def register_embeddings_provider(
         >>> embeddings = load_embeddings("fakeembeddings:fake-embeddings",size=1024)
         >>> embeddings.embed_query("hello world")
 
-        Register with OpenAI-compatible API:
+        # Register with OpenAI-compatible API:
         >>> register_embeddings_provider(
-        ...     "vllm", "openai-compatible", base_url="http://localhost:8000/v1"
+        ...     "vllm",
+        ...     "openai-compatible",
+        ...     base_url="http://localhost:8000/v1"
         ... )
         >>> embeddings = load_embeddings("vllm:qwen3-embedding-4b")
         >>> embeddings.embed_query("hello world")
@@ -95,7 +100,7 @@ def register_embeddings_provider(
                 "when embeddings_model is a string, the value must be 'openai-compatible'"
             )
 
-        _check_langchain_openai_install()
+        _check_pkg_install("langchain_openai")
 
         _EMBEDDINGS_PROVIDERS_DICT.update(
             {
@@ -126,32 +131,44 @@ def batch_register_embeddings_provider(
 ):
     """Batch register embeddings providers.
 
-    This function allows you to register multiple embeddings providers at once, which is
-    useful when setting up applications that need to work with multiple embedding services.
+    This function allows you to register multiple embeddings providers at once,
+    which is useful when setting up applications that need to work with multiple
+    embedding services.
 
     Args:
         providers: List of EmbeddingProvider dictionaries, each containing:
             - provider_name: str - Provider name
-            - embeddings_model: Union[Type[Embeddings], str] - Model class or provider string
-            - base_url: The API address of the Embedding model provider (optional, valid for both types of `embeddings_model`, but mainly used when `embeddings_model` is a string and is "openai-compatible")
+            - embeddings_model: Union[Type[Embeddings], str] - Model class or
+                provider string
+            - base_url: The API address of the Embedding model provider
+                (optional, valid for both types of `embeddings_model`, but
+                mainly used when `embeddings_model` is a string and is
+                "openai-compatible")
 
     Raises:
         ValueError: If any of the providers are invalid
 
     Example:
-        Register multiple providers at once:
+        # Register multiple providers at once:
         >>> from langchain_dev_utils.embeddings import batch_register_embeddings_provider, load_embeddings
         >>> from langchain_core.embeddings.fake import FakeEmbeddings
         >>>
         >>> batch_register_embeddings_provider(
         ...     [
-        ...         {"provider_name": "fakeembeddings", "embeddings_model": FakeEmbeddings},
-        ...         {"provider_name": "vllm", "embeddings_model": "openai-compatible", "base_url": "http://localhost:8000/v1"},
+        ...         {
+        ...             "provider_name": "fakeembeddings",
+        ...             "embeddings_model": FakeEmbeddings,
+        ...         },
+        ...         {
+        ...             "provider_name": "vllm",
+        ...             "embeddings_model":  "openai-compatible",
+        ...             "base_url": "http://localhost:8000/v1"
+        ...         },
         ...     ]
         ... )
         >>> embeddings = load_embeddings("vllm:qwen3-embedding-4b")
         >>> embeddings.embed_query("hello world")
-        >>> embeddings = load_embeddings("fakeembeddings:fake-embeddings",size=1024)
+        >>> embeddings = load_embeddings("fakeembeddings:fake-embeddings", size=1024)
         >>> embeddings.embed_query("hello world")
     """
     for provider in providers:
@@ -185,12 +202,12 @@ def load_embeddings(
         ValueError: If provider is not registered or API key is not found
 
     Example:
-        Load model with provider prefix:
+        # Load model with provider prefix:
         >>> from langchain_dev_utils.embeddings import load_embeddings
         >>> embeddings = load_embeddings("vllm:qwen3-embedding-4b")
         >>> embeddings.embed_query("hello world")
 
-        Load model with separate provider parameter:
+        # Load model with separate provider parameter:
         >>> embeddings = load_embeddings("qwen3-embedding-4b", provider="vllm")
         >>> embeddings.embed_query("hello world")
     """
